﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using GrxCAD.ApplicationServices;
using GrxCAD.DatabaseServices;
using GrxCAD.EditorInput;
using GrxCAD.Geometry;
using GrxCAD.Runtime;

namespace BreakSample_CS_
{
	public class sample : IExtensionApplication
	{
		//初期化処理
		public void Initialize()
		{
			Editor icEd = Application.DocumentManager.MdiActiveDocument.Editor;
			icEd.WriteMessage("\nサンプルの.NETアセンブリをロードしました");
		}

		//解放処理
		public void Terminate()
		{
		}

		[CommandMethod("BREAKSAMPLE")]
		public void BreakSample()
		{
			var db = Application.DocumentManager.MdiActiveDocument.Database;
			var ed = Application.DocumentManager.MdiActiveDocument.Editor;
			var res1 = ed.GetEntity("\n点で分割する直線・曲線を選択");
			if (res1.Status != PromptStatus.OK) return;
			using (var trans = db.TransactionManager.StartTransaction())
			{
				using (var ent = trans.GetObject(res1.ObjectId, OpenMode.ForRead) as Entity)
				{
					if(ent is Curve)
					{
						var crv = ent as Curve;						
						if (crv is Circle || crv is Ellipse)
						{
							ed.WriteMessage("\n円、楕円は点で分割できません");
							return;
						}
						var res2 = ed.GetPoint("\n分割点を指定");
						if (res2.Status != PromptStatus.OK) return;
						var breakPt = crv.GetClosestPointTo(res2.Value, false);
						var crvs = crv.GetSplitCurves(new Point3dCollection(new Point3d[] { breakPt }));
						if (crvs.Count == 0) return;
						var curSpace = trans.GetObject(db.CurrentSpaceId, OpenMode.ForWrite) as BlockTableRecord;
						foreach (Curve obj in crvs)
						{
							curSpace.AppendEntity(obj);
							trans.AddNewlyCreatedDBObject(obj, true);
						}
						crv.UpgradeOpen();
						crv.Erase();
					}
					else
					{
						ed.WriteMessage("\n選択されたオブジェクトは直線・曲線ではありません");
						return;
					}
				}					
				trans.Commit();
			}
		}
	}
}
